@@ -47,7 +47,7 @@ OPT_HDRS = [b'message-id']
 KEYCACHE = dict()
 
 # My version
-__VERSION__ = '0.4.0'
+__VERSION__ = '0.4.1'
 MAX_SUPPORTED_FORMAT_VERSION = 1
 
 
@@ -933,6 +933,11 @@ def validate_message(msgdata: bytes, sources: list, trim_body: bool = False) ->
             signtime = pm.validate(i, pkey, trim_body=trim_body)
             attestations.append((RES_VALID, i, signtime, keysrc, algo, errors))
         except ValidationError:
+            if keysrc is None:
+                # Not in default keyring
+                errors.append('%s/%s no matching openpgp key found' % (i, s))
+                attestations.append((RES_NOKEY, i, t, None, algo, errors))
+                continue
             errors.append('failed to validate using %s' % keysrc)
             attestations.append((RES_BADSIG, i, t, keysrc, algo, errors))
 
@@ -1014,7 +1019,10 @@ def cmd_genkey(cmdargs, config: dict) -> None:
 
     # Do we have the signingkey defined?
     usercfg = get_config_from_git(r'user\..*')
-    if not config.get('identity') and usercfg.get('email'):
+    if not config.get('identity'):
+        if not usercfg.get('email'):
+            logger.critical('This operation requires user.email to be set')
+            sys.exit(1)
         # Use user.email
         config['identity'] = usercfg.get('email')
 
